# Table of Contents

- [general-modeling-guidelines](<./general-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [General Modeling Guidelines](<./General-Modeling-Guidelines.md>)
  - [General Guidelines](<./General-Modeling-Guidelines/General-Guidelines.md>)
  - [Example: Modeling SAP LeanIX as an Application](<./General-Modeling-Guidelines/Example-Modeling-SAP-LeanIX-as-an-Application.md>)
  - [Was this page helpful?](<./General-Modeling-Guidelines/Was-this-page-helpful.md>)
